@@ -1,7 +1,7 @@
 import logging
 import numpy as np
-from clease.montecarlo.observers import MCObserver
 from clease.tools import add_file_extension
+from .mc_observer import MCObserver
 
 logger = logging.getLogger(__name__)
 
@@ -41,6 +41,6 @@ class EnergyEvolution(MCObserver):
 
         :param fname: File name of .csv file. Adds extension if none is given.
         """
-        full_fname = add_file_extension(fname, '.csv')
+        full_fname = add_file_extension(fname, ".csv")
         np.savetxt(full_fname, self.energies, delimiter=",")
         logger.info("Energy evolution data saved to %s.", full_fname)
