@@ -23,21 +23,27 @@ from clease.montecarlo.constraints import ConstrainSwapByBasis
 
 logger = logging.getLogger(__name__)
 
-__all__ = ('StructureGenerator', 'GSStructure', 'MetropolisTrajectory', 'ProbeStructure')
+__all__ = (
+    "StructureGenerator",
+    "GSStructure",
+    "MetropolisTrajectory",
+    "ProbeStructure",
+)
 
 
-# pylint: disable=too-few-public-methods
 # pylint: disable=too-many-instance-attributes
 class StructureGenerator(ABC):
     """Base class for generating new strctures."""
 
-    def __init__(self,
-                 settings,
-                 atoms,
-                 init_temp=None,
-                 final_temp=None,
-                 num_temp=5,
-                 num_steps_per_temp=10000):
+    def __init__(
+        self,
+        settings,
+        atoms,
+        init_temp=None,
+        final_temp=None,
+        num_temp=5,
+        num_steps_per_temp=10000,
+    ):
         if not isinstance(settings, ClusterExpansionSettings):
             raise TypeError(f"Settings must be a ClusterExpansionSettings object, got {settings}")
 
@@ -52,12 +58,14 @@ class StructureGenerator(ABC):
             if len(atoms) != len(settings.atoms):
                 raise ValueError("Passed Atoms has a wrong size.")
         else:
-            raise ValueError("concentration of the elements in the provided"
-                             " atoms is not consistent with the settings.")
+            raise ValueError(
+                "concentration of the elements in the provided"
+                " atoms is not consistent with the settings."
+            )
 
         # eci set to 1 to ensure that all correlation functions are included
         # but the energy produced from this should never be used
-        self.eci = {name: 1. for name in self.cf_names}
+        self.eci = {name: 1.0 for name in self.cf_names}
         calc = Clease(self.settings, eci=self.eci)
         self.atoms.calc = calc
         self.output_every = 30
@@ -91,7 +99,7 @@ class StructureGenerator(ABC):
         self._reset()
 
         temps = np.logspace(math.log10(self.init_temp), math.log10(self.final_temp), self.num_temp)
-        now = time.time()
+        now = time.perf_counter()
         change_element = self._has_more_than_one_conc()
 
         N = len(temps)
@@ -107,7 +115,7 @@ class StructureGenerator(ABC):
             while count < self.num_steps_per_temp:
                 count += 1
 
-                if time.time() - now > self.output_every:
+                if time.perf_counter() - now > self.output_every:
                     acc_rate = float(num_accepted) / count
                     msg = (
                         f"T Step: {Ti+1:>{len_max_temp}} of {N}, "
@@ -116,12 +124,13 @@ class StructureGenerator(ABC):
                         # Print same len as max required
                         f"MC Step: {count:>{len_num_steps}d} of "
                         f"{self.num_steps_per_temp}, "
-                        f"Accept. rate: {acc_rate*100:.2f} %")
+                        f"Accept. rate: {acc_rate*100:.2f} %"
+                    )
                     logger.info(msg)
-                    now = time.time()
+                    now = time.perf_counter()
 
                 if choice([True, False]) and self.alter_composition:
-                    logger.debug('Change element type? %s', change_element)
+                    logger.debug("Change element type? %s", change_element)
                     # Change element Type
                     if change_element:
                         self._change_element_type()
@@ -129,10 +138,9 @@ class StructureGenerator(ABC):
                         continue
                 else:
                     indx = self._swap_two_atoms()
-                    logger.debug('Swapping indices %s', indx)
-                    if self.atoms[indx[0]].symbol == \
-                            self.atoms[indx[1]].symbol:
-                        logger.debug('Same symbols detected, skipping.')
+                    logger.debug("Swapping indices %s", indx)
+                    if self.atoms[indx[0]].symbol == self.atoms[indx[1]].symbol:
+                        logger.debug("Same symbols detected, skipping.")
                         continue
                 self.atoms.get_potential_energy()
 
@@ -140,7 +148,7 @@ class StructureGenerator(ABC):
                     num_accepted += 1
                     self.atoms.calc.clear_history()
                 else:
-                    self.atoms.calc.restore()
+                    self.atoms.calc.undo_system_changes()
 
         # Create a new calculator and attach it to the generated structure
         calc = Clease(self.settings, eci=self.eci, init_cf=self.cf_generated_structure)
@@ -161,9 +169,11 @@ class StructureGenerator(ABC):
 
     def _accept(self) -> bool:
         """Determine if we accept the last change."""
+        # pylint: disable=no-self-use
         return True
 
     def _estimate_temp_range(self):
+        # pylint: disable=no-self-use
         return 1.0, 1e5
 
     def _determine_temps(self):
@@ -171,13 +181,13 @@ class StructureGenerator(ABC):
         self._reset()
         count = 0
         max_count = 100
-        now = time.time()
+        now = time.perf_counter()
         # To avoid errors, just set the temperature to an arbitrary file
         self.temp = 10000000.0
         while count < max_count:
-            if time.time() - now > self.output_every:
+            if time.perf_counter() - now > self.output_every:
                 logger.info("Progress (%.3f %%)", 100 * count / max_count)
-                now = time.time()
+                now = time.perf_counter()
 
             if choice([True, False]) and self.alter_composition:
                 # Change element Type
@@ -188,8 +198,7 @@ class StructureGenerator(ABC):
                     continue
             else:
                 indx = self._swap_two_atoms()
-                if self.atoms[indx[0]].symbol == \
-                        self.atoms[indx[1]].symbol:
+                if self.atoms[indx[0]].symbol == self.atoms[indx[1]].symbol:
                     continue
                 count += 1
             self.atoms.get_potential_energy()
@@ -271,19 +280,21 @@ class StructureGenerator(ABC):
 
     def _check_consistency(self):
         # Check to see if the cf is indeed preserved
-        final_cf = \
-            self.corrFunc.get_cf_by_names(
-                self.generated_structure,
-                self.atoms.calc.cf_names)
+        final_cf = self.corrFunc.get_cf_by_names(self.generated_structure, self.atoms.calc.cf_names)
         for k in final_cf:
-            if abs(final_cf[k] - self.cf_generated_structure[k]) > 1E-6:
-                msg = 'Correlation function changed after simulated annealing'
+            if abs(final_cf[k] - self.cf_generated_structure[k]) > 1e-6:
+                msg = "Correlation function changed after simulated annealing"
                 logger.error(msg)
 
                 # Print a summary of all basis functions (useful for debuggin)
-                logger.debug('Basis functions:')
+                logger.debug("Basis functions:")
                 for k2 in final_cf:
-                    logger.debug('   %s: %s, %s', k2, final_cf[k2], self.cf_generated_structure[k2])
+                    logger.debug(
+                        "   %s: %s, %s",
+                        k2,
+                        final_cf[k2],
+                        self.cf_generated_structure[k2],
+                    )
                 raise ValueError(msg)
 
     def _get_full_cf_matrix(self):
@@ -291,13 +302,12 @@ class StructureGenerator(ABC):
         cfm = []
         db = connect(self.settings.db_name)
         tab_name = f"{self.settings.basis_func_type.name}_cf"
-        for row in db.select(struct_type='initial'):
+        for row in db.select(struct_type="initial"):
             cfm.append([row[tab_name][x] for x in self.cf_names])
         cfm = np.array(cfm, dtype=float)
         return cfm
 
 
-# pylint: disable=too-many-instance-attributes
 class ProbeStructure(StructureGenerator):
     """Generate probe structures.
 
@@ -337,26 +347,29 @@ class ProbeStructure(StructureGenerator):
                   Reads sigma and mu from 'probe_structure-sigma_mu.npz' file.
     """
 
-    def __init__(self,
-                 settings,
-                 atoms,
-                 init_temp=None,
-                 final_temp=None,
-                 num_temp=5,
-                 num_steps_per_temp=1000,
-                 approx_mean_var=False):
+    def __init__(
+        self,
+        settings,
+        atoms,
+        init_temp=None,
+        final_temp=None,
+        num_temp=5,
+        num_steps_per_temp=1000,
+        approx_mean_var=False,
+    ):
 
-        StructureGenerator.__init__(self, settings, atoms, init_temp, final_temp, num_temp,
-                                    num_steps_per_temp)
+        StructureGenerator.__init__(
+            self, settings, atoms, init_temp, final_temp, num_temp, num_steps_per_temp
+        )
         self.o_cf = self.atoms.calc.cf
         self.o_cfm = np.vstack((self.cfm, self.o_cf))
         self.approx_mean_var = approx_mean_var
-        fname = 'probe_structure-sigma_mu.npz'
+        fname = "probe_structure-sigma_mu.npz"
         if not approx_mean_var:
             if os.path.isfile(fname):
                 data = np.load(fname)
-                self.sigma = data['sigma']
-                self.mu = data['mu']
+                self.sigma = data["sigma"]
+                self.mu = data["mu"]
                 self.o_mv = mean_variance(self.o_cfm, self.sigma, self.mu)
             else:
                 raise IOError(f"'{fname}' not found.")
@@ -445,16 +458,19 @@ class GSStructure(StructureGenerator):
         Dictionary containing cluster names and their ECI values
     """
 
-    def __init__(self,
-                 settings,
-                 atoms,
-                 init_temp=2000,
-                 final_temp=10,
-                 num_temp=10,
-                 num_steps_per_temp=100000,
-                 eci=None):
-        StructureGenerator.__init__(self, settings, atoms, init_temp, final_temp, num_temp,
-                                    num_steps_per_temp)
+    def __init__(
+        self,
+        settings,
+        atoms,
+        init_temp=2000,
+        final_temp=10,
+        num_temp=10,
+        num_steps_per_temp=100000,
+        eci=None,
+    ):
+        StructureGenerator.__init__(
+            self, settings, atoms, init_temp, final_temp, num_temp, num_steps_per_temp
+        )
         self.alter_composition = False
         self.eci = eci
         calc = Clease(self.settings, eci=eci)
@@ -489,7 +505,6 @@ class GSStructure(StructureGenerator):
 
 
 class MetropolisTrajectory:
-
     def __init__(self, settings, atoms, num):
         self.settings = settings
         self.atoms = atoms
@@ -497,27 +512,29 @@ class MetropolisTrajectory:
 
     def generate(self):
         cnst = ConstrainSwapByBasis(self.atoms, self.settings.index_by_basis)
-        eci = {'c0': 0.0}
+        eci = {"c0": 0.0}
         calc = Clease(self.settings, eci=eci)
         self.atoms.calc = calc
 
         mc = Montecarlo(self.atoms, 10000000)
         mc.generator.add_constraint(cnst)
-        fname = 'metropolis_traj'
+        fname = "metropolis_traj"
         obs = Snapshot(self.atoms, fname=fname)
         mc.attach(obs, interval=1)
 
         mc.run(steps=self.num)
 
         reader = TrajectoryReader(obs.fname)
-        all_atoms = [a for a in reader]
+        all_atoms = list(reader)
+        reader.close()
+        obs.close()
         os.remove(obs.fname)
         return all_atoms
 
 
 def mean_variance_full(cfm):
     prec = precision_matrix(cfm)
-    mv = 0.
+    mv = 0.0
     for x in range(cfm.shape[0]):
         mv += cfm[x].dot(prec).dot(cfm[x].T)
     mv = mv / cfm.shape[0]
