@@ -4,6 +4,7 @@
 
 #include <array>
 #include <map>
+#include <memory>
 #include <set>
 #include <string>
 #include <unordered_map>
@@ -20,18 +21,9 @@
 #include "symbol_change.hpp"
 #include "symbols_with_numbers.hpp"
 
-// Read values from name_list
-// name_list[symm_group][cluster_size] = vector of string variables of all the cluster names
-typedef std::vector<std::vector<std::vector<std::string>>> name_list;
-
-// Read values form cluster_list
-// cluster_list[symm_group][cluster_size][indx] = vector of indices belonging to the cluster #indx.
-typedef std::vector<std::vector<std::vector<std::vector<std::vector<int>>>>> cluster_list;
 typedef std::vector<std::map<std::string, double>> bf_list;
 typedef std::array<SymbolChange, 2> swap_move;
-typedef std::unordered_map<std::string, Cluster> cluster_dict;
 
-// typedef std::unordered_map<std::string,double> cf;
 typedef NamedArray cf;
 
 enum class Status_t {
@@ -70,9 +62,6 @@ class CEUpdater {
     CEUpdater();
     ~CEUpdater();
 
-    /** New copy. NOTE: the pointer has to be deleted */
-    CEUpdater *copy() const;
-
     /** Initialize the object (cluster_info should contain duplication factors) */
     void init(PyObject *py_atoms, PyObject *settings, PyObject *corrFunc, PyObject *eci,
               PyObject *cluster_list);
@@ -192,27 +181,25 @@ class CEUpdater {
 
     unsigned int cf_update_num_threads{1};
 
-    // std::vector<std::string> symbols;
-    Symbols *symbols_with_id{nullptr};
-    // std::vector<cluster_dict> clusters;
+    std::unique_ptr<Symbols> symbols_with_id{nullptr};
+
     ClusterList clusters;
     std::vector<int> trans_symm_group;
     std::vector<int> trans_symm_group_count;
     std::map<std::string, int> normalisation_factor;
 
-    // bf_list basis_functions;
-    BasisFunction *basis_functions{nullptr};
+    std::unique_ptr<BasisFunction> basis_functions{nullptr};
 
     Status_t status{Status_t::NOT_INITIALIZED};
-    // Matrix<int> trans_matrix;
     RowSparseStructMatrix trans_matrix;
+
     std::map<std::string, int> ctype_lookup;
     NamedArray eci;
     std::map<std::string, std::string> cname_with_dec;
     std::vector<bool> is_background_index;
     bool ignore_background_indices{true};
     bool assume_no_self_interactions{false};
-    CFHistoryTracker *history{nullptr};
+    std::unique_ptr<CFHistoryTracker> history{nullptr};
     PyObject *atoms{nullptr};
     std::vector<std::string> singlets;
     // Pre-parsed names of the ECI values.
